/* libiso8601/src/libiso8601/100_leap.c
 *
 *  (c)2006, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv2. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



static int leap_second_days[] = {
    720439, /* 1972-06-30 */
    720623, /* 1972-12-31 */
    720988, /* 1973-12-31 */
    721353, /* 1974-12-31 */
    721718, /* 1975-12-31 */
    722084, /* 1976-12-31 */
    722449, /* 1977-12-31 */
    722814, /* 1978-12-31 */
    723179, /* 1979-12-31 */
    723726, /* 1981-06-30 */
    724091, /* 1982-06-30 */
    724456, /* 1983-06-30 */
    725187, /* 1985-06-30 */
    726101, /* 1987-12-31 */
    726832, /* 1989-12-31 */
    727197, /* 1990-12-31 */
    727744, /* 1992-06-30 */
    728109, /* 1993-06-30 */
    728474, /* 1994-06-30 */
    729023, /* 1995-12-31 */
    729570, /* 1997-06-30 */
    730119, /* 1998-12-31 */
    732676, /* 2005-12-31 */
    733772, /* 2008-12-31 */
};



int iso8601_seconds_leap(const struct iso8601_date* date)
{
    int num_ly = 0, i = 0;

    num_ly = sizeof(leap_second_days) / sizeof(int);
    for(i = 0; i < num_ly; ++i) if(leap_second_days[i] == date->day) return 86401;
    return 86400;
}



static int _leap_elapsed_day(int sday, int eday)
{
    int spos, epos;

    for(spos = 0; (unsigned)spos < sizeof(leap_second_days) / sizeof(int); ++spos) {
        if(sday <= leap_second_days[spos]) break;
    }
    for(epos = 0; (unsigned)epos < sizeof(leap_second_days) / sizeof(int); ++epos) {
        if(eday <= leap_second_days[epos]) break;
    }

    return epos - spos;
}



int iso8601_leap_elapsed(const struct iso8601_date* start, const struct iso8601_date* end)
{
    return _leap_elapsed_day(start->day, end->day);
}



/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
